package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(@@`````````0```````
M`+%X``````!``#@`"0!``!<`%@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````&``````````8``````````$````!
M````!0```````````````````````````````````````*00````````I!``
M```````0``````$````&````````J\````````"[P````````+O`````````
M!,`````````%&````````!```````@````8```````"KT````````+O0````
M````N]`````````!X`````````'@``````````@````$````!`````````)0
M`````````E`````````"4``````````D`````````"0`````````!&1TY5``
M```$````````G8@```````"=B````````)V(`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O`````````N\``````
M``"[P`````````1`````````!$```````````2]L:6(O;&0M;75S;"US,SDP
M>"YS;RXQ``````0````4`````T=.50#:]7W><8$@/%]>X+0.Y^E^TPN@<```
M```````1````10````0````(@`1`!0`0$""$`(:`!!``*`D$``D"`*&""`($
MND$8@(@`````````10```$D```!-````3@```%4```!6````5P````````!9
M````6@````````!;````7````%X``````````"U'WLX?W\5N?)I_:@[OT^NV
MF\4N#O&-N`[D_R!\U&35'%AQV6^+`;*;PT^8+#_EPH?7^D)@;*'Z?)+CN@'&
M1^/2/,-59LRO9]-P!XCLU45#[=MB,\PEC!6;G*E_"@*GX%">&FM)^^"C````
M```````````````````````````````````````#```(````````&$@`````
M`````````H`2`````````````````````````````902````````````````
M`````````````$L2`````````````````````````````F\2````````````
M`````````````````6@2`````````````````````````````#T2````````
M`````````````````````1D2`````````````````````````````=<2````
M`````````````````````````*H2`````````````````````````````+,B
M`````````````````````````````3$2````````````````````````````
M`;P2`````````````````````````````ET2````````````````````````
M`````7D2`````````````````````````````/P2````````````````````
M`````````G@2`````````````````````````````K\A````````````````
M`````````````#<2`````````````````````````````KX1````````````
M`````````````````:\1`````````````````````````````2`2````````
M`````````````````````D82`````````````````````````````%L2````
M`````````````````````````?82`````````````````````````````L`1
M`````````````````````````````)L2````````````````````````````
M`AT2`````````````````````````````!\@````````````````````````
M`````482`````````````````````````````-T@````````````````````
M`````````&,2`````````````````````````````),2````````````````
M`````````````/<2`````````````````````````````%,2````````````
M`````````````````$02`````````````````````````````!`2````````
M`````````````````````A02`````````````````````````````H<2````
M`````````````````````````8@2`````````````````````````````'(@
M`````````````````````````````J@2````````````````````````````
M`C82`````````````````````````````>,2````````````````````````
M``````$2`````````````````````````````^D2````````````````````
M`````````B@2`````````````````````````````J`2````````````````
M``````````````D1`````````````````````````````@02````````````
M`````````````````&02`````````````````````````````F02````````
M`````````````````````!@2`````````````````````````````0(2````
M`````````````````````````-@2`````````````````````````````546
M`````````````````````````````J\2````````````````````````````
M`HX2`````````````````````````````(X2````````````````````````
M`````*,2`````````````````````````````&D2````````````````````
M`````````3@2`````````````````````````````E$2````````````````
M`````````````1,2`````````````````````````````,(@````````````
M`````````````````<T2`````````````````````````````)H2````````
M`````````````````````=(2`````````````````````````````W$2```*
M````````.'@````````&.````WX2```*````````02@`````````S@```IL2
M```*````````'X@````````"@````:D2```+````````7/```````````@``
M`O42```*````````*L``````````!@```_42```(````````&$@`````````
M`@```RH2```*````````*L@````````";````S\2```*````````/K``````
M```"=````XH0```4````````P(```````````````Q`2```*````````-&@`
M````````=@```S<2```*````````-.``````````=````U42```*````````
M*6``````````.````V82```*````````60`````````!E@```Y82```*````
M````-Y@`````````V@```\40```4````````P-@``````````````\H2```*
M````````+3@`````````-````UT2```*````````(C@`````````/````QX2
M```*````````+7`````````!8@```P81```3````````P'@`````````"```
M`[X0```3````````P(```````````````X\2```*````````(@@`````````
M`````_(2```*````````6)``````````;````]<2```*````````-V@`````
M````+````Z@2```*````````*9@````````!)````_L2```*````````6I@`
M```````"5````N@2```*````````+M@````````%C`!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E
M:P!G971P:60`=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S=')R8VAR`&QS=&%T
M`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T
M<G-T<@!V9G!R:6YT9@!S=')C:'(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`
M7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`;65M
M8W!Y`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`<VYP<FEN=&8`<F5A9&1I<@!S=')C
M<'D`<W1R=&]K`%]?;&EB8U]S=&%R=%]M86EN`'-P<FEN=&8`<W1R9'5P`'!T
M:')E861?871F;W)K`%]?96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"US
M,SDP>"YS;RXQ`'!A<E]I;FET7V5N=@!P87)?8W5R<F5N=%]E>&5C`&UY7W!A
M<E]P;`!P87)?96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!P
M87)?9&EE`%A37TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`%]S=&%R=%]C
M`'-H85]U<&1A=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P`%]?8G-S7W-T
M87)T`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X96-?<')O8P!?
M961A=&$`7V5N9`!P87)?8F%S96YA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<VAA7VEN:70`<VAA7V9I;F%L`"]U<W(O;&EB+W!E<FPU+V-O<F5?
M<&5R;"]#3U)%````````````````N\``````````#````````"-0````````
MN\@`````````#````````"+H````````OZ``````````#````````!A(````
M````O]``````````#````````!^(````````O^``````````#````````%SP
M````````P```````````#````````,``````````P!@`````````#```````
M`%_Z````````P"``````````#````````%U8````````P#``````````#```
M`````%WX````````P#@`````````#````````%W\````````P$``````````
M#````````%_N````````P$@`````````#````````%U>````````P%``````
M````#````````%_V````````P&``````````#````````%_>````````P&@`
M````````#````````%_D````````P'@`````````#````````&``````````
MOX@````&````"@``````````````````OY`````+````"@``````````````
M````OY@````5````"@``````````````````OZ@````:````"@``````````
M````````O[`````=````"@``````````````````O[@````?````"@``````
M````````````O\`````I````"@``````````````````O\@````K````"@``
M````````````````O]@````L````"@``````````````````O^@````Q````
M"@``````````````````O_`````X````.```````````````````O_@```!!
M````"@``````````````````O<@````"````"P``````````````````O=``
M```#````"P``````````````````O=@````$````"P``````````````````
MO>`````%````"P``````````````````O>@````'````"P``````````````
M````O?`````(````"P``````````````````O?@````)````"P``````````
M````````O@`````*````"P``````````````````O@@````+````"P``````
M````````````OA`````,````"P``````````````````OA@````-````"P``
M````````````````OB`````.````"P``````````````````OB@````/````
M"P``````````````````OC`````0````"P``````````````````OC@````1
M````"P``````````````````OD`````3````"P``````````````````OD@`
M```6````"P``````````````````OE`````7````"P``````````````````
MOE@````8````"P``````````````````OF`````9````"P``````````````
M````OF@````;````"P``````````````````OG`````<````"P``````````
M````````OG@````=````"P``````````````````OH`````>````"P``````
M````````````OH@````@````"P``````````````````OI`````A````"P``
M````````````````OI@````B````"P``````````````````OJ`````C````
M"P``````````````````OJ@````D````"P``````````````````OK`````E
M````"P``````````````````OK@````F````"P``````````````````OL``
M```G````"P``````````````````OL@````H````"P``````````````````
MOM`````J````"P``````````````````OM@````M````"P``````````````
M````ON`````N````"P``````````````````ON@````O````"P``````````
M````````OO`````P````"P``````````````````OO@````R````"P``````
M````````````OP`````S````"P``````````````````OP@````T````"P``
M````````````````OQ`````U````"P``````````````````OQ@````V````
M"P``````````````````OR`````W````"P``````````````````OR@````Y
M````"P``````````````````OS`````Z````"P``````````````````OS@`
M```[````"P``````````````````OT`````\````"P``````````````````
MOT@````]````"P``````````````````OU`````^````"P``````````````
M````OU@````_````"P``````````````````OV````!`````"P``````````
M````````OV@```!!````"P``````````````````OW````!"````"P``````
M````````````OW@```!#````"P``````````````````OX````!$````"P``
M````````Z^_P<``DN00`#Z?[_V#C`/```"3K[_$0``0'_N,0\#@`),`0``!2
MH]('\#`0".,0$!``!`?Q!P`'``<`P!```%*BXQ`0```$!_$-$.,0$`P`%,#T
M____Y0````#`$```4I;C$!````0'\0T0XQ`0#``4P/3____5````&,`0``!2
MBN,0$```!`?Q#1#C$!`,`!3`]/___\4````PP!```%)^XQ`0```$!_$-$.,0
M$`P`%,#T____M0```$C`$```4G+C$!````0'\0T0XQ`0#``4P/3___^E````
M8,`0``!29N,0$```!`?Q#1#C$!`,`!3`]/___Y4```!XP!```%):XQ`0```$
M!_$-$.,0$`P`%,#T____A0```)#`$```4D[C$!````0'\0T0XQ`0#``4P/3_
M__]U````J,`0``!20N,0$```!`?Q#1#C$!`,`!3`]/___V4```#`P!```%(V
MXQ`0```$!_$-$.,0$`P`%,#T____50```-C`$```4BKC$!````0'\0T0XQ`0
M#``4P/3___]%````\,`0``!2'N,0$```!`?Q#1#C$!`,`!3`]/___S4```$(
MP!```%(2XQ`0```$!_$-$.,0$`P`%,#T____)0```2#`$```4@;C$!````0'
M\0T0XQ`0#``4P/3___\5```!.,`0``!1^N,0$```!`?Q#1#C$!`,`!3`]/__
M_P4```%0P!```%'NXQ`0```$!_$-$.,0$`P`%,#T___^]0```6C`$```4>+C
M$!````0'\0T0XQ`0#``4P/3___[E```!@,`0``!1UN,0$```!`?Q#1#C$!`,
M`!3`]/___M4```&8P!```%'*XQ`0```$!_$-$.,0$`P`%,#T___^Q0```;#`
M$```4;[C$!````0'\0T0XQ`0#``4P/3___ZU```!R,`0``!1LN,0$```!`?Q
M#1#C$!`,`!3`]/___J4```'@P!```%&FXQ`0```$!_$-$.,0$`P`%,#T___^
ME0```?C`$```49KC$!````0'\0T0XQ`0#``4P/3___Z%```"$,`0``!1CN,0
M$```!`?Q#1#C$!`,`!3`]/___G4```(HP!```%&"XQ`0```$!_$-$.,0$`P`
M%,#T___^90```D#`$```47;C$!````0'\0T0XQ`0#``4P/3___Y5```"6,`0
M``!1:N,0$```!`?Q#1#C$!`,`!3`]/___D4```)PP!```%%>XQ`0```$!_$-
M$.,0$`P`%,#T___^-0```HC`$```45+C$!````0'\0T0XQ`0#``4P/3___XE
M```"H,`0``!11N,0$```!`?Q#1#C$!`,`!3`]/___A4```*XP!```%$ZXQ`0
M```$!_$-$.,0$`P`%,#T___^!0```M#`$```42[C$!````0'\0T0XQ`0#``4
MP/3___WU```"Z,`0``!1(N,0$```!`?Q#1#C$!`,`!3`]/___>4```,`P!``
M`%$6XQ`0```$!_$-$.,0$`P`%,#T___]U0```QC`$```40KC$!````0'\0T0
MXQ`0#``4P/3___W%```#,,`0``!0_N,0$```!`?Q#1#C$!`,`!3`]/___;4`
M``-(P!```%#RXQ`0```$!_$-$.,0$`P`%,#T___]I0```V#`$```4.;C$!``
M``0'\0T0XQ`0#``4P/3___V5```#>,`0``!0VN,0$```!`?Q#1#C$!`,`!3`
M]/___84```.0P!```%#.XQ`0```$!_$-$.,0$`P`%,#T___]=0```ZC`$```
M4,+C$!````0'\0T0XQ`0#``4P/3___UE```#P,`0``!0MN,0$```!`?Q#1#C
M$!`,`!3`]/___54```/8P!```%"JXQ`0```$!_$-$.,0$`P`%,#T___]10``
M`_#`$```4)[C$!````0'\0T0XQ`0#``4P/3___TU```$",`0``!0DN,0$```
M!`?Q#1#C$!`,`!3`]/___24```0@P!```%"&XQ`0```$!_$-$.,0$`P`%,#T
M___]%0``!#C`$```4'KC$!````0'\0T0XQ`0#``4P/3___T%```$4,`0``!0
M;N,0$```!`?Q#1#C$!`,`!3`]/___/4```1HP!```%!BXQ`0```$!_$-$.,0
M$`P`%,#T___\Y0``!(#`$```4%;C$!````0'\0T0XQ`0#``4P/3___S5```$
MF,`0``!02N,0$```!`?Q#1#C$!`,`!3`]/___,4```2PP!```%`^XQ`0```$
M!_$-$.,0$`P`%,#T___\M0``!,C`$```4#+C$!````0'\0T0XQ`0#``4P/3_
M__RE```$X,`0``!0)N,0$```!`?Q#1#C$!`,`!3`]/___)4```3XP!```%`:
MXQ`0```$!_$-$.,0$`P`%,#T___\A0``!1#`$```4`[C$!````0'\0T0XQ`0
M#``4P/3___QU```%*`````#K;_`P`"3C\/\X_W'C,/"H`"3C0/"@`"10(/"T
M04#PH$$P\*A!(/"TLD\`L.N[`"``#;)/`+'2!_#`L"C`Y?___=#$2```4`?$
M*```3]RY!``TP.7___\5Q!@``$_<E0`0`*>$`+;`,```4`'C4#````18H/"T
M[)H`!`#8N10`Z>-EL```!.LN``,`#98#9(JGJ@`#P.7___]4XQ#PJ``$P#``
M`!_7XP`0```$XS`@"``DXP`@```DN00`4L0K``!0/L!````?R.-`4!@`),0H
M``!0$>,@4!``)%B0\+3LG`#%`7[LZ0`#`-CL"?__`-A!,!`(IR@`!*<!``&G
M=`""B````;D4`$+L$@`!`-CKY``#``VY%`!AXT`P```$XTY0```DZQ8``P`-
MXV`P"``$XV%0```DIRH``J<[`!"G!O_C[&D``P#8N10`EKD4`$KKJ0`#``U!
M*E``IVD``.5((````,`P```#_L0H``!/[\#E___\UNPH`%0`?L0H``!/YD%@
M\+S`Y?___?NY!``VN00`DL`@```>1\#E```!-^PH`$<`?,0H``!/T<#E___^
M^,#E___^M=4'\,"P**=T`%FY!``IZV_P^``$!_[`Y?___A?$*P``3[KL*`!.
M`'S`Y?___$[`,```3T'C(#````3C0K````22`$E^I_3_..,P,```!.,P4"``
M)*<H``5!,!`0["[_=F!VI_3_E,0H``!/E<#E___]3*?T_ZG`4```3XGC(%``
M``*GA``'P.4```^QI_3_L;D$`#;`(```'</`Y0```-O$*P``3W3L*/^D`'RG
M]/_MIV@`!*?T_V[`Y?___$:G*0`!P.7___WQN00`+\`P````$N,P,```&*?[
M_V"G"0``XP#P```DP/0````)!P<'!P``F:`'!P<'ZV_P,``D04`@"./P_UC_
M<<1H``!.S.5(\*```,18``!.IN,P(`0`%,0H``!.N,#E___]W^MO\-@`!`?^
M!P<'!\`0``!/!,`@``!/`>P2``J`9,08``!.F^P8``0`?`?Q!_X'!P<'!P?`
M$```3O#`(```3NVY"0`2ZP$``P`*ZS$`/P`,N0@`,.LS``$`"NPX``T`?,08
M``!.=NP8``<`?,`@``!.U`?Q!_X'!P<'!P?KO_!8`"3`L```3LGC\/]@_W&5
M`+``IW0`(\`0``!.1^,0$````J>$``C$*```3G?`Y?__^S;`Y?___ZW`(```
M3D;C$"````*GA``(P"```#V6P.7___P%D@&P`.N_\/@`!`?^!P<'!\`0``!.
M5.,0$````J>$`!?K[_!P`"3`,```3I'C\/]@_W'`(```/7?`Y?___<;K[_$0
M``3`]/___X[`]/___XOK;_`P`"3C\/]@_W'L*`!<`'S$&```3@/C<!````*G
MA`!3N00`@KD$`&/C`"```)2Y!`"2E0`@`*>$`$[L"``,/7Y!D)`!XP"0``"4
ME0"0`*=T__8;F..@<````J>$`!^Y%`"9N00`M[D$`$FY!``XN00`*L#E___[
M\.PF``D`?D$IH`"5/2``IX0`#T&PL`CCH+````*G=/_IN00`*NMO\-``!`?^
M0:F@`;GI<#NY!``JZT,``P`*4$!@`.MO\-``!`?^IZD``+D$`"KK;_#0``0'
M_J>8``"G]/^_!P<'!^NO\%``)./P_LC_<;)/`+"Y!`"BZ[L`(``-03#PH+)/
M`+'2!_$PL"C`Y?__^W;L)@`A`'X8$J<X0`!8(/"XP"L``/``[",`"(!VI0^@
M`.P@`!-@=KD$`"JG.0`"P.7___QL$!*G&O__B!``'Z?T``2G&```U0?Q,+`H
MN10`(:=T``;KK_&(``0'_L#E___ZQ>N/\$``)./P_LC_<;)/`(#KB``@``VR
M3P"!T@?Q,(`H["@`"0!\N00`LI4`(`"G=``+U0?Q,(`HIW0`D>N/\7@`!`?^
MP.7___O`N00`DNPH__(`?+D$`"G`Y?__^G;L*`!A`'Q!H"`3E2X@$Z=T``:5
M`*`!IX3_\)4N(!.GA`!>IP@``+D$`#JY!``;ITD``+)>`$.G%/_^N0D`2J<I
M``"R7@`AIQ3__KD)`"L:)*<J``*Y%``BP.7___H7N00`6L`P```;J+D$`**Y
M!`!+P.7___NKN00`*D$P\*#`Y?__^\3L*``-_WY8`/"XIUA``,`+``#P`.P%
M`"N`=KD$`"K`Y?__^P*Y!``JP.7___RMN00`*<#E___Z&.PF_Z4`?+D$`"G`
MY?___#"Y!``KP.7___G[I_3_?Y4NH`&G=/^BE0"@`J>$_XBG]/^<N00`*L#E
M____6*?T_]C`Y?__^A7K;_`P`"3C\/](_W&R3P!@ZV8`(``-LD\`8;D$`++2
M!_"P8"BY!`"CE3TP`*=T``1!H#`!IP@``+D$`!JGB0``N00`*[)>`(&G%/_^
M03#PK+D)`(K`Y?___F[L*`"7`'RG"```I]D``+D$`.*R7@#>IQ3__KD)`-+L
MC0!VP&7C`/"L`!3$V```3&+K<``#``WC(+```)2Y!`!+E0"P`*=T``VG]`#F
M04!``>,@0```E)4`0`"GA``%[";_]SU^N0D`2[D4`)1!*)`"N00`A^.`T```
M",#E___Y6.,@@```).PH`#D`?.,PT```!.-0L```D./G,```!$)0X`!!<+`!
M&`7L5@`0`'RG]``\XQ!P``"00A"P`4%P<`$8`>P8`#(`?$(`\*"Y!`"^E3WP
MH$'@X`&G=/_MDCVP`*?9``#C3:```)!"3;`!I]L``>Q&__D`?-4'\+!@**=T
M`)7K;_#H``0'_J>9``#CB:```)!"B2``IYL``>R&__D`?*?T_^NY!`"^I_3_
MV<38``!+X.-PT```!.,0<````J>$`&ZY!`!'IY@``!@IIYH``4%`0`CC,$``
M``*G=/_XIRH``[D4``+K(``#``W`,```3$CC$#```!*G=``VP%```$Q`Y4Q0
M```!P.7___C0XR#PH``D["C_L0!\N10`Z;D$`#?K?@`#``VY!`!'P.7___@N
MXR#PH``$XR#0```D4)#PK.-0\*``!*>:``&Y%`"9ZSD``P`-01-0`.5($```
M`*?T_RJY!``RN00`)\#E___YON,@\*``).,@T```).PH_WP`?+D4`$GK=``#
M``VG]/_8IYD``*?T_RJG*0`0IY@``*?T_Z7`Y?__^-'K;_`P`"3`$```2X'C
M\/]8_W'CL!````3`4```.CC$2```2V'`,```&@6R3P"@ZZH`(``-LD\`H>,K
MH```!,!@```;5\#E___X_+D$`%;E2/"@``#`0```"KKC*Z````3`,```&?7`
MY?__^#OK;_#8``0'_@<'!P>R3P`@P!```$M&ZS(`(``-XT`0```$LD\`,<!0
M```Y^^,D,```!,1(``!+(<`P```9Q<#T___XR>MO\#``)./P\`#_<>,`__@`
M(./P\`#_<>,`__@`(./P_U#_<>,`\*@`(.,0\*@"<;)/`)#KF0`@``VR3P"1
M0;#PIM('$`"0*,#E___WDL!@```9L;D$`%+`0```&:ZY!``KISD0`<#E___W
M<^PH`%7_?KD$``+C@/"G`7&Y!``KN00`..P`$``@<:=)$`#`Y?__]Y^Y!`!B
M["0`/P!^IRH``;D4`"+`Y?__]].Y!`"B["@`,P!\N10`MNPH``>@9;GHL#*Y
M84"#[*@`(2!EN00`.+D$`$NY!``J[+`0`2!QP.7___=605N@`)(`4`#CX/"H
M`G'5!^``D"BG=``2N00`*NMO\.`"!`?^N>BP2+EA0*2G]/_>IZD``*?T_^K`
MY?__]^<'!P<'P/3___]L!P?K;_`P`"3C\/``_W'C`/_X`"#C\/ZX_W'C`/%`
M`"#C$/%``7&Y!`"RN00`D[)/`'!!,/"LZW<`(``-P"```!DLLD\`<=('$`!P
M*,#E___\/Z<Y`"^Y!`"BN00`*\#E___YH.PH`!D`?,`@```9&KD$`#O`Y?__
M_9.Y!``KXX#Q0`%QU0>``'`HIW0`[^MO\7@!!`?^N00`*<#E___XHL`P```9
M!L#E___X?+D$`%+L*/_=`'Q!D/%`08#PL)4`4`"GA`"8[*@`#P!\IP@``+D$
M`#6Y!``JLET`,J<4__ZGA`!XIP@``*=)``"Y!`!ELEX`1J<4__ZYZ5`DXQ!/
M__]Q[%$`-Z!EN>E0`:<!``&GA``.E2\0`*=T`""2`!``XQ`?__]Q[%$`&8!D
MZ^```0`,E2\0`*=T`!&2`!``ZR\?__]5IW0`"NL`'___4N,0'_[_<:?G_^^G
M"```IRD``+D$`#6R7@`CIQ3__KD)`"6G"```ITD``+D$`&NGZ0__LEX`1J<4
M__ZY"0!+000@`>P._VT@9>.P\*``)+D$`"G`8```&(?`0```&/VG.1``P.7_
M__8WIU@0`*<J``'L)0`HP'>G]``!E0"@`:=T`!K`,```&&ZG*0``P.7___?B
MN00`4NPH_T,`?)4`4`"G=/]L[*@`!P!\E2Z@`*>$_^:G*0`!P%```!A'I_3_
ML[D$`#BY!``IP.7___A$[";_V@!^6!#PR*4_@`#`&P``\`#L$__08':Y!``I
MISD``<#E___X4.PF_\8`?KD$`#G`(```&"C`Y?___*.Y!``IP.7___?`I_3_
M#<#E___VJP<'!P?KO_!8`"2G.0`OX_#_8/]QN00`LL#E___VO.PH``4`?$&P
M(`&Y!``KZ[_P^``$P/3___>?!P<'!^NO\%``)./P\`#_<>,`__@`(./P_UC_
M<>,`\*``(+)/`+#C$/"@`7'KNP`@``VR3P"QT@<0`+`H["@`:P!\N00`,I4`
M(`"GA`!DIP@``*=)``"R7@!"IQ3__J<)$`"Y"0!#ITL``>Q``'<@94&@\*"Y
M!``JP.7___50IP@``*<Y``"Y!`!:LEX`-:<4__[C$#___W'L&@`?P&6YZ:#A
MIQ$``:=T`$?K3@`!``R5+Q``IW0`$9(`$`#K+Q___U6G=``*ZP`?__]2XQ`?
M_O]QIT?_[[D$`"JG.0`OP.7___8]["@`%P!\["H`,R!EN00`*L#E___W(N,P
M\*`!<=4',`"P**=T`"WKK_#X`00'_N,@\*`!<=4'(`"P**=T`"'`(```%V7K
MK_#X`03`]/__]P65+Q``IW3_SY(`$`#C$!___W'L&O^R8&2G]/_%D@`@`*?T
M_\ZG*0``I_3_S\#E___UW`<'!P<'!^NO\%``)./P_U#_<;)/`*#KJ@`@``VR
M3P"A0;#PI-('\*B@*+D$`#O`(```%SO`Y?__^D7L*``N`'SC0/"D`!3$*```
M2$CK%``#``WC$"````CC4!`(``3C4!```"3L6/_C`'SC`!`0``3C`!`(`"1!
M$!`([`;_^`!\N00`.\`@```7$,#E___Z&NPF_]@`?+D$`#O`(```%PK`Y?__
M^@_L*``N`'SC$/"D`!3$6```2!+KX0`#``WCX%````CC`.`(``3C`.```"3L
M"/_C`'SC,.`0``3C,.`(`"1!X.`([#;_^`!\N00`.\`@```6W\#E___YY.PF
M_]@`?+D$`#O`(```%MC`Y?__^=GL*``N`'SC4/"D`!3$Z```1]SK10`#``WC
M0.````CC,$`(``3C,$```"3L./_C`'SC($`0``3C($`(`"1!0$`([";_^`!\
MN00`.\`@```6K<#E___YKNPF_]@`?+D$`#O`(```%J?`Y?__^:/L*``N`'SC
M,/"D`!3$*```1Z;K$P`#``WC$"````CC0!`(``3C0!```"3L2/_C`'SC`!`0
M``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```6?,#E___Y>.PF_]@`?+D$`#O`
M(```%G7`Y?__^6WL*``N`'SC$/"D`!3$2```1W#K40`#``WC4$````CC`%`(
M``3C`%```"3L"/_C`'SCX%`0``3CX%`(`"1!4%`([.;_^`!\N00`.\`@```6
M2L#E___Y0NPF_]@`?+D$`#O`(```%D?`Y?__^3?L*``N`'SC0/"D`!3$6```
M1SKK-``#``WC,%````CCX#`(``3CX#```"3LZ/_C`'SC(#`0``3C(#`(`"1!
M,#`([";_^`!\N00`.\`@```6',#E___Y#.PF_]@`?+D$`#O`(```%>G`Y?__
M^0'L*``N`'SCX/"D`!3$*```1P3K'@`#``WC$"````CC,!`(``3C,!```"3L
M./_C`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```5OL#E___XUNPF
M_]@`?+D$`#O`(```%>'`Y?__^,OL*``N`'SC$/"D`!3$.```1L[K00`#``WC
M0#````CC`$`(``3C`$```"3L"/_C`'SC4$`0``3C4$`(`"1!0$`([%;_^`!\
MN00`.\`@```5ML#E___XH.PF_]@`?+D$`#O`(```%;#`Y?__^)7L*``N`'SC
M,/"D`!3$2```1ICKXP`#``WCX$````CC4.`(``3C4.```"3L6/_C`'SC(.`0
M``3C(.`(`"1!X.`([";_^`!\N00`.\`@```5A<#E___X:NPF_]@`?+D$`#O`
M(```%7_`Y?__^%_L*``N`'SC4/"D`!3$Z```1F+K%0`#``WC$.````CC(!`(
M``3C(!```"3L*/_C`'SC`!`0``3C`!`(`"1!$!`([`;_^`!\N00`.\`@```5
M5,#E___X-.PF_]@`?+D$`#O`(```%1;`Y?__^"GL*``N`'SC$/"D`!3$*```
M1BSK,0`#``WC,"````CC`#`(``3C`#```"3L"/_C`'SC0#`0``3C0#`(`"1!
M,#`([$;_^`!\N00`.\`@```4Z\#E___W_NPF_]@`?+D$`#O`(```%1C`Y?__
M]_.Y!``R["@`"0!\P"```!4#P.7___E0N00`.\`@```5#L#E___WX+D$`#+L
M*``)`'S`(```%0S`Y?__^3VY!``[P"```!4*P.7___?-N00`,NPH`!H`?,`@
M```4JL#E___Y*M4'\*B@**=T`"/`,```%:K`(```%+SKK_$```3`]/__^1FY
M!``[P"```!3NP.7___>IN00`,NPH_^4`?,`@```4M,#E___Y!J?T_]S`Y?__
M\Q,'!P<'Z[_P6``DP"```!2DX_#_4/]QLD\`L$$P\*3KNP`@``VR3P"QT@?P
MJ+`HP.7___=_["@`'`!\OR$@`*>$`!?`)P```#"YA``"N0,`$.PQ/[\!5=4'
M\*BP*+D4`".G=``*Z[_Q"``$!_ZG.```I_3_\\#E___RU@<'8`#P@&`@\(A@
M0/"08&#PF.L_\!@`),08``!%>>/P_SC_<;D$`#)!`/%HLD\`($%0\,CK0@`@
M``VR3P!!XR`0```$T@?PP$`HXP#PL``DXU#PN``DY4CPH``!Y4CPJ```04#P
MH,#E___U`*<I`/_`Y?__]$L'!P<'ZX_P0``DX^#P`/!QX_#P`/]QXP#_^``@
MN2$`_J<D__BY!`#^X_#_4/]QXP#PJ``@XQ#PJ!!QN00`@K)/`*"G20`"ZZH`
M(``-ISD``+)/`*'2!Q``H"C`Y?__\EOLDO__`-GL"3"``%7LE`"Z`'RY"0"0
M0;#PH.R4`)\`?+D$`#FY!``HITD``,#E___R0NPH`+C_?+D$`#NY!``HP$$`
M`0`(P.7___+E["@`I?]^N10`,NP\`'@'?>,3O_C_<>P;`')`9>Q!/K\`5<!0
M``!$\]4'4``0`*>$`'WC$!___W'L&P!A0&7L2``M`'SL2``<`7SL2``.`GS`
MX```1-S5!^``$`"GA`!FXQ`?__]QP"```$31U0<@`!``IX0`6^,0'___<<`P
M``!$QM4',``0`*>$`%#C$!___W'L&P`T0&7`0```1+C5!T``$`"GA`!"XU`?
M__]QP.```$2MN00`%=4'X`!0`*>$`#7C$%___W'`(```1*#5!R``$`"GA``J
MQ`@``$28XQ!?_O]QXP!?_O\@IX0`'^,07_W_<>P;_]*@9<*4``$``,`Q__\`
M`.R3_V=@9*<I___C@/"H$''5!X``H"BG=``CZX_P\!`$!_ZYZ;`AN0@`*:?T
M__"G"___P"'__P``N8$``J<+``&G]/]`P"```!-UP.7___[(P"```!-HP.7_
M__["P.7___&1Z^_P<``DX_#_8/]QP.7___$8P.7___*U["@`!@!\XR`@```$
MZ^_Q$``$!_X'!P<'ZV_P,``DX_#_4/]QLD\`H+D$`++KJ@`@``U!,/"DLD\`
MH<`@```30]('\*B@*,#E___UY>PH`$``?+D$`&*5`"``IX0`.;D$`#O`Y?__
M\>'L*``,`'S5!_"HH"BG=``\ZV_PX``$!_ZG"```N00`&[D$`#:G20``LEX`
M0Z<4__ZY"0!&LEX`(:<4__ZY"0`K02)``L#E___PW+D$`$O`4```$IZY!`"R
MP#```!,3P.7___)OU0?PJ*`HIW0`#;D$`#O`(```$O/K;_#@``3`]/__]OW`
MY?__\0P'!P<'!P?K;_`P`"3C\/X@_W&R3P!PZW<`(``-LD\`<<`0``!#N]('
M\=AP*-(/\+@0$-('\,@0(-(O\.@0*-(/\-`06-('\.`0:$&0\+2Y!`#2N00`
M.<`@```22<#E___U8>PH``D`?+D$`+*5`"``IW0"1L#E___P7\#E___Q_.PH
M`0P`?..`(````J>$`0:G"```IRD``+D$`#BR7@`CIQ3__KD)`"CK(@`!``VG
M*P`!P.7___!@XT"```"4N00`LKD$`&*5`(``IX0`%[D$`"NYA`!$P#```!*(
MP.7___'K08"``4&PL`+C0(```)25`(``IW3_[4&@\/#`(```$D6G]``)IZL`
M".,@K_C_`J>$`""Y!``YP.7___4#N00`@NPH__(`?)4`(`"GA/_MP.7___5G
M["C_Z`!^N00`*,#E___Q>;D$`++L)@`=`'Q!H/"XX["@```"IX0`%94`L`"G
MA`"7N00`*\#E___U2NPF`((`?J>K``CCL*````*G=/_OIP@``+D$`%:Y!``K
MISD``*=)``"R7@`RIQ3__K)>`$6G%/_^N0D`.[D)`$8:-*<Z!`2Y%`"CN00`
M*L#E___OVN-@\*``)+D$`(+`,```$A*Y!`!+P&```!(*P%```!&2P.7___%G
MN00`**<Y`<#`Y?__\D#L)@`+_W[`Y?__\:I8`"``[`8!91%^N00`*$$P\1C`
MY?__\'X8LNPF``T`?EA@\3"GZ$``P&L``/``[&X`>(!VN00`6.-`T```!,2(
M``!"FL`P```1^.,@@```!,#E___P'Z>I``#5!_'8<"BG=`'DN00`*NMO\A``
M!`?^N00`*Z>K``C`Y?__\-NY!`"R["C_9P!\I_3_?*>Y``"G]/]X0:#PT.,@
MH````J>$`!6Y!``YP.7___0Z["@`!P!\E0`@`*=T`!FGJP`(XR"@```"IW3_
M[Z<I``W`@```$8?`Y?__[TZG2`!3N00`LKD$`&*G]/[SP.7___"CN00`@NPH
M_^0`?+D$`!*G"```I^D``+)>`.&G%/_^N0D`XNLN``$`#:<K``&G]/[*6&#Q
M-,#E___O!NQB_X9@=E@0\3"G.`'`P!L```'_[!/_?&!VN00`*L#E___O%+D$
M`#FY!`"BP"```!&:P.7___/@N00`,NPH`-H`?.,@T```!,#E___W<;D$`&+L
M*`#/`'RG"```ITD``+D$`":R7@!"IQ3__KD)`$;L3``>`WZY%`!4P.```!%V
MXQ5O_/]QLET`X:<4__ZG=``/[$@!%01^ITK_^[D4`#1!0V``E2]``*>$`0JY
M!``YP"```!"TP.7___.>["@`GP!\XY`@``"4[)@`F0!^[)@`EC!^P#```!%_
MP"```!"?P.7___3QP.7__^Y`P````!&EN00`8KD$`$BY!``JXP#PH``DP%``
M`!!IP#```!%"P.7___`[I_0`*L#E___PAEA`(`"G3@`1IW0`*\#E___N'<!0
M```1@J>Z``&Y%``;N00`8N-0\*@`)+D$`$BY!``JP%```!!"XQ#PH``DP#``
M`!$?P.7___`1N00`*J<Y`<#`Y?__\.KL*/_1_WZY!``HP.7___$BN00`.L`@
M```0&,#E___TF+D$`"K`Y?___2^G]/[(N00`6+D4`&#C0-````3$*```04O`
M,```$(OC("````3`Y?__[M"G]/ZQP.7___T5U0?QV'`HIW0`DKD$`"OK;_(0
M``3`]/__[X[C8-````2G]/\QN00`)J<Y``#`Y?__\%*Y!`#2["C_9`!^P.7_
M__O4N00`8NPD_UP`?*=)``#C,&_V_W&Y!``MP.7__^Y+N00`+4$P\:FG20`&
MP.7__^[R["8`7P9\P#```"_'U04P`/&IIW3_/>,P;\[_<:=)``"Y!``MP.7_
M_^XM06#QK[D$`"VY!``VITD`*,#E___NTNPF`#\H?,#@```0U+D$`$BY!``J
MD@#QU^/@\*``),!0```/F,`P```0:<#E___O:J?T_V/CT-`(``*GA/[UIP@`
M`*<I``"Y!`!=LEX`):<4__ZY"0`M["S^YP-]X^+?_/]QP!```!!!LET`'J<4
M__ZYXH!MI_3^V,#E___M\\`@```0-L#E___[&^MO\#``)./P_U#_<<"@``!`
MFK)/`+#C$*````3KNP`@``VR3P"QXY&P```$08#PI-('\*BP*-(`D+&0L+D$
M`#C`(```#U7`Y?__\DWL*``'`'R5,2``IX0`S<#E___WY^,@H```!..2L```
M!+D$`"FG60`#ITD``<`P```0$L#E___O"[D$`&+L*``?`'SC,"`0``3C<*``
M``3C,#````3`0```#__C)[````3`Y?__[<3C0&`0``3C,$````210#`-IW0`
MNN-PH```!*=9``/C)[````2G20`!P#````_EP.7__^[:N00`DNPH`!P`?+D$
M`#C`(```#N#`Y?__\?.Y!`!"["@`?`!\XS"0$``$XR>P```$XS`P```$P.7_
M_^V,XZ"@```$ITD``>-ZL```!,`P```/NKD$`"?`Y?__[DS`0```#[VY!``R
MN00`)\#E___M<KD$`#C`(```#JCCBK````22`("QP.7___&[Q"L``$!4["@`
M*P!\ISD!P,#E___O6NP"``$`V.P,`!<!?^PH`!01?KD$`%+$N```0#K$2```
M0#OC,+````3`(```#YO`Y?__["#5!_"HL"BG=`!7ZV_PX``$!_[$*```0"+`
MY?__^_O$*P``0"#L)O_/`'S`(```#V_`Y?__[`65`"`!IX3_/*?T_S'`Y?__
M]':Y!`!B["@`(`!\XQ"0$``$N00`0N,P$```!.,GL```!,#E___M";D$`";`
MY?__[T2G]/]XXR>P```$P.7__^PLI_3_0N-0D!``!,3H```_XN,GL```!.,P
M4```!.-`X```!,#E___LZ*?T_US`Y?__[+,'!P<'ZY_P2``DX_#_4/]QLD\`
MH+D$`++KJ@`@``U!,/"DLD\`H<`@```.-M('\*B@*,#E___Q'>PH`!,`?.,0
M(```E.P8``T`?NP8``HP?NRX``<`?)4`L`"G=``+U0?PJ*`HIW0`-.N?\/@`
M!`?^N00`*\#E___U[*<Y`"^Y!`"2P.7__^R/["@`!0!\09`@`;D$`"G`Y?__
M[76G20`$P#````Y-P.7__^T-[";_V0!^U0?PJ*`HIW0`"KD$`"OKG_#X``3`
M]/__\8O`Y?__[$H'!^MO\#``)./P_-#_<;)/`+#KNP`@``VR3P"Q01#PJ-('
M\RBP**<)``1!4"`XXT!0```$XS!0"``$ZZ0`(``,XZ`0```DZV,`(``,XV`0
M$``DP$H`````XT`0"``DP#H`````XS`0&``D05!0$*<;`""G!__>XS#Q$``$
MXX#Q&``$XQ#Q(``$XY#PJ``$XP#PL``$04#PN*>I`$"Y!`!QX]!````$N00`
M[>/@0#``@KF"`..Y@@#I[!X@OR%5[!X@/@%6XQ!`<``DN00`.+D$`)"Y!`"'
MITL`"*>G"MCCX"````3C8"`(``3C8/"@`"3C0"`0``3C`"`8``3LKB"_)56Y
MYP"4[*X@.@56N8``EKF"`)#K5@`"``SC</"P``3L5@`A'E;">EJ">9GL-2"_
M`%6Y"`!PN><PU.,0\*@`!+F``-["&EJ">9FY@@#4XQ`@(``(N>APC;D(`!KK
MK@`"``RY"``9[*X`(1Y6[)$@OP!5N>>@9;F``&FY@@!C[-$[OR55XU#PP``$
M[-D`.@56PEI:@GF9N0@`V+D(`%/L?2"_`%7LC3N_)57K.0`"``SLAP`Z!5;L
M.0`A'E;C$/"X``3"&EJ">9FY"``4N0@`%NQJ(+\`5;F"`*.Y"``8N>1PBNR1
M(+\`5>S1.[\E5;D$`*WLJ0`Z!5:Y@@"&XQ#PR``$N0@`A<(:6H)YF;D(`(JY
MZ&!1ZZ<``@`,[&,@OP!5[*<`(1Y6['@@OP!5[(@[OR55[(<`.@56N8(`.N/0
M\-``!+F``#G"VEJ">9FY@@`VN0@`-;GH8%VY"``X[&H@OP!5ZXD``@`,[(D`
M(1Y6[),@OP!5N8(`J.PS.[\E5;GD<!KCT/#8``2Y@@`6PMI:@GF9N0@`%;D$
M`*.YZ&!=[*D`.@56[&@@OP!5N0@`&NLW``(`#.PW`"$>5KF"`(/L<2"_`%7L
MH3N_)56YY)`8N00`BNR'`#H%5KF"`!;CT/#@``2Y"``5PMI:@GF9N0@`&+GH
M8%WLH3N_)57L8R"_`%7KB0`"``SLB0`A'E;LD2"_`%7LJ0`Z!5:Y@@`XXQ#P
MZ``$N8``-\(:6H)YF;F"`#:Y"``UN>A@4;D(`#KL:""_`%7KIP`"``SLIP`A
M'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#P\``$N0@`
M-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3
M.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\/@`!+D(`#7"&EJ">9FY"``ZN>A@
M4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'
M`#H%5KF"`#;C$/$```2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7L
MB0`A'E:Y@@"H[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z!5:Y@@`VXQ#Q"``$
MN0@`-<(:6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`(1Y6N8(`BNQS(+\`
M5>S3.[\E5;GDD#BY!`"-[(<`.@56N8(`-N,0\1``!+D(`#7"&EJ">9FY"``X
MN>A@4>N)``(`#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7LTSN_)56YY'`ZN00`
MK>RI`#H%5KF"`#;C$/$8``2Y"``UPAI:@GF9N0@`.KGH8%'KIP`"``SL:""_
M`%7LIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#Q
M(``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3
M(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\2@`!+D(`#7"&EJ">9FY
M"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`X
MN00`C>R'`#H%5KF"`#;C$/$P``2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL
M:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55XQ#Q.``$N>1P.L(:6H)YF;F"
M`#:Y!`"MN0@`->RI`#H%5KGH8%&Y"``Z[&@@OP!5[-,[OR55ZZ<``@`,[-,@
M.@56[*<`(1Y6P#H`````N>>@>..`\4``!+F``'G"BEJ">9FY@@!VN>A@&+D(
M`'7K60`"``RY"`!][%D`(1Y6[)<[OR55[)<@.@56[&H@OP!5N>=0VNN#``(`
M#+F``-.Y@@#6N0@`T;D(`-FY!`"8[),`(1Y6[#T[OR55N>>0%>P](#H%5KF"
M`!?CH/%(``3C@/%0``3"JF[9ZZ'"BF[9ZZ&Y"`"FN1H`A;D:`*'L9R*_/E6Y
M"`"C[&<"(1Y6[#H[OR55N>=@&>PZ(#H%5KF"`!WL?2*_/E6Y&@"!['T"(1Y6
MN0@`@^,P\5@`!,(Z;MGKH;GG<%:Y&@`YN>>@E>P8.[\E5;D:`#GL&"`Z!5;C
MD/%@``2Y"``QPIINV>NA[-,[OR55N1H`ENS3(#H%5NQJ(K\^5>QJ`B$>5N.@
M\6@`!+GG8%?"JF[9ZZ&Y@@!8N1H`I[D:`)7L>"*_/E6Y"`"=['@"(1Y6[(D[
MOR55[(D@.@56N>=PUK/!`&CC@/%P``3"BF[9ZZ&Y&@"&L\T`9KF"`-.Y&@"M
MN0@`INQ:.[\E5>Q:(#H%5NQC(K\^5>,0\7@`!.QC`B$>5L(:;MGKH;GG8#>Y
M&@`7N8(`.>QY(K\^5;D:`(/L>0(A'E:Y"`"%N>=P5NR8.[\E5;F"`%KLF"`Z
M!5:Y&@`5XS#Q@``$N0@`&<(Z;MGKH>R:(K\^5;D:`#;LF@(A'E;LT3N_)56Y
MYY!7[-$@.@56N8(`6..@\8@`!+D:`#7"JF[9ZZ&Y"``]N1H`I^QX(K\^5>QX
M`B$>5NR#.[\E5>R#(#H%5KGG<-FSP0!XXX#QD``$PHINV>NAN1H`B;/-`)>Y
M@@#1N1H`K;D(`*GL6CN_)57L6B`Z!5;L82*_/E7L80(A'E;C$/&8``2YYV#7
MPAINV>NAN8(`T[D:`!>Y&@"-[',BOSY5N0@`A>QS`B$>5NPX.[\E5;GG<%;L
M."`Z!5:Y@@!:XY#QH``$N1H`%<*:;MGKH;D(`!.Y&@"6[#HBOSY5[-$[OR55
M[#H"(1Y6[-$@.@56N><P5^.@\:@`!+F"`%C"JF[9ZZ&Y&@"5N1H`I[D(`)WL
M>"*_/E7L>`(A'E;LB3N_)57LB2`Z!5:YYW#3L\$`:..`\;``!,**;MGKH;D:
M`(.SS0`VN8(`T;D:`*VY"`"C[%H[OR55[%H@.@56[&$BOSY5[&$"(1Y6XQ#Q
MN``$N>=@U\(:;MGKH;F"`-FY&@`7N1H`C>QY(K\^5;D(`(7L>0(A'E;LF#N_
M)56YYW!6[)@@.@56N8(`6N,P\<``!+D:`!7".F[9ZZ&Y"``9N1H`-NR:(K\^
M5>S1.[\E5>R:`B$>5NS1(#H%5KGGD%?CH/'(``2Y@@!8PJINV>NAN1H`-;D:
M`*>Y"``]['@BOSY5['@"(1Y6[(,[OR55[(,@.@56N>=PV;/!`'CC@/'0``3"
MBF[9ZZ&Y&@")L\T`E[F"`-'L82*_/E6Y&@"M[&$"(1Y6N>=@U[F"`-.Y"`"I
MN1H`C>Q:.[\E5>S3(K\^5>Q:(#H%5NS3`B$>5KGGT):Y@@":N0@`A>,0\=@`
M!.PX(+\`5>Q8.[\E5<(:;MGKH>Q3`#H%5KD:`!>Y&@`9[)HBOSY5N0@`%>R:
M`B$>5N.@\>``!+GGD'W"JF[9ZZ&Y@@"'N1H`INQA(+\`5>P1.[\E5>P6`#H%
M5KD:`*CC@/'H``2Y"`"APHJ/&[S<ZQ,``@`,N1H`C>P3`"$>5NS1(+\`5;GD
MT%FSP0`H[#H[OR55[(H@OP!5N>80J;F``*:Y@0"EL\T`4N-P\?``!,)ZCQN\
MW.PX`#H%5KD(`*6Y!`!7XW#Q^``$N1H`6<)ZCQN\W.N6``(`#.R6`"$>5KGD
MT&FY@0`9N>C0U[F``!BY@0`6N0@`%;D(`*.SP0!M[#H@OP!5[*H[OR55[*,`
M.@56N0@`H>L8``(`#.P8`"$>5NS1(+\`5;GDT%GL:B"_`%7LBCN_)56YYA"I
MN8``H[F!`*6SS0!6[(8`.@56XW#R```$N0@`I;D(`*C">H\;O-SK@P`"``RY
M!`!7[(,`(1Y6N1H`6>PZ.[\E5>R:(+\`5;F!`!BYY-"HN8``%KF!`!JY"``5
M[#D`.@56XW#R"``$N0@`,<)ZCQN\W.L6``(`#+GHT-?L%@`A'E;L82"_`%6Y
MY&!8L\$`/;GF$-BY@`#9N8$`U;/-`%/L<R"_`%7L,SN_)57L-P`Z!5:Y"`#5
MN0@`T^LY``(`#.PY`"$>5KGD8).Y@0`3XZ#R$``$N8``%\*JCQN\W+F!`!FY
M!`!:N1H`6.R-(+\`5;D(`!7LW3N_)57LV``Z!5:Y"`#1[)T@OP!5ZQ<``@`,
M[!<`(1Y6XW#R&``$PGJ/&[S<N>A@9^QQ(+\`5;GD<%.YYA"CL\$`=KF``*BY
M@0"EL\T`5^S=.[\E5>-@\B``!+D(`*7LV0`Z!5;":H\;O-RY"`#:N00`5NRM
M(+\`5;D:`%/LW3N_)57K.``"``SLV@`Z!5;L.``A'E:YYC"!N>1P$[F``(FY
M@0"!ZQD``@`,N0@`A>P9`"$>5KD(`(WLT2"_`%6YY-!3N>80D^-@\B@`!+F`
M`)K":H\;O-RY@0"5N0@`9[/!`":SS0!2['@@OP!5XV#R,``$N0@`E<)JCQN\
MW.R(.[\E5;D$`%;LAP`Z!5:Y&@!3N>B`.>N:``(`#.R:`"$>5KGDT*FY@0`9
MN8``%[F!`!JY"``5[(,@OP!5[&,[OR55XS#R.``$[&@`.@56PCJ/&[S<N0@`
M8>L7``(`#.P7`"$>5NQQ(+\`5;GD<%FYZ-#3N>80.;/!`&VY@``XN8$`-;/-
M`%;CT/)```3"VH\;O-SLIB"_`%6Y"``U[&8[OR55N00`7>QJ`#H%5KD:`%GC
MT/)(``3KF``"``S"VH\;O-SLF``A'E:YY'")N8$`&;GH<'VY@``:N8$`&+D(
M`!6Y"``VL\$`-^QC(+\`5>PS.[\E5>PV`#H%5KGH,%'K&@`"``SL&@`A'E;L
MT2"_`%6YY-!YN>80J;F``*:Y@0"GL\T`<^PU(+\`5>R%.[\E5;D(`*?L@P`Z
M!5:Y"`"HXU#R4``$['H@OP!5[(H[OR55PEJ/&[S<XZ#R6``$N1H`6<*JCQN\
MW.N6``(`#.R6`"$>5KGDT&FY@0`9N>C0VKF``!.Y@0`6N0@`%>R'`#H%5K/!
M`'VY"`"!ZQ,``@`,[!,`(1Y6[-$@OP!5N>306;GF$*FY@`"GN8$`I;/-`%?L
M:""_`%7L.#N_)56Y"`"E[#8`.@56XX#R8``$PHJ/&[S<N00`6+D:`%GKEP`"
M``SLEP`A'E:YY-!YN8$`&;F``!:Y@0`7N0@`%;D(`*/C@/)H``3L.B"_`%7"
MBH\;O-SLJCN_)57LHP`Z!5:Y"`"AZQ8``@`,[!8`(1Y6[&$@OP!5N>1@6>QZ
M(+\`5;GHT-CLBCN_)56SP0`MN>80J;F``*.Y@0"EL\T`4NR'`#H%5N/0\G``
M!+D(`*7"VH\;O-RY"`"HN00`7;D:`%GLVB"_`%7KDP`"``SLDP`A'E;L.CN_
M)56YY&")N8$`&>P]`#H%5KF``!?CH/)X``2Y@0`8PJJ/&[S<N0@`%;GH8%JY
M"``Q[&,[OR55[&,@.@56ZQ<``@`,L\$`9NP7`"$>5N-@\H``!.R!(+\`5;GF
M$'FYY("IPFJ/&[S<N1H`:;/-`):Y@`!]N8$`>KD(`'6YZ)"7[%D[OR55[%D@
M.@56L\$`%NM]``(`#.Q]`"$>5KD$`-6SS0!1N>2`I^-@\H@`!,)JRF+!UKGH
M@(;`.@````"Y@0`7L\$`.+F``!/K@P`"``RY@0`:[(,`(1Y6N0@`%;/-`&.Y
M"``=XZ#RD``$N>>`U\*JRF+!UKF"`-FY&@"G['DBOSY5['D"(1Y6XY#RF``$
MPIK*8L'6N1H`F+/!`%JSP0`)L\T`E;D:`&WL,3N_)57L,2`Z!5:Y"``V[%,[
MOR55[%,@.@56N>=PJ+F"`*&Y&@":N0@`E;/-`%#L82*_/E7L80(A'E:YYV#7
MN8(`T^P9.[\E5;D:`%WL&2`Z!5:Y"``5[*$[OR55[*$@.@56L\$`*K/-`-+C
M@/*@``3CH/*H``3"BLIBP=;"JLIBP=:Y&@"'N1H`INQS(K\^5>QS`B$>5KGG
M<#;L:2*_/E6Y@@`Y[&D"(1Y6N1H`@[GG8%>Y"`"-N8(`4>R8.[\E5;D:`*7L
MF"`Z!5:Y"`"I[-H[OR55[-H@.@56[)$BOSY5XS#RL``$[)$"(1Y6PCK*8L'6
MN>>05KD:`#>Y@@!8N1H`-;D(`#WLTSN_)57LTR`Z!5;C$/*X``2SP0`=PAK*
M8L'6X]#RP``$N1H`%L+:RF+!UNQH(K\^5;D:`-GL:`(A'E:YYV")L\T`D;F"
M`(KL>B*_/E6Y&@`8['H"(1Y6N0@`&;GG<(;L43N_)56Y@@"#[%$@.@56XZ#R
MR``$PJK*8L'6N1H`IKD$`&WLTR*_/E6Y&@!HN0@`9>S3`B$>5KGGT#>Y@@`Q
M[%8[OR55N1H`H^Q6(#H%5KD(`*7L.CN_)57L.B`Z!5;C@/+0``3"BLIBP=:Y
M&@"'['$BOSY5['$"(1Y6XQ#RV``$N>=P7<(:RF+!UKF"`%:Y&@`=N1H`A>S6
M(K\^5;D(`(/LU@(A'E;L.#N_)56YY]!G[#@@.@56N8(`:KD:`!:Y"``3[#HB
MOSY5[#H"(1Y6N><P;;F"`&CL43N_)57CD/+@``3L42`Z!5;"FLIBP=:Y&@"7
MN1H`ENQH(K\^5;D(`)7L:`(A'E;LB3N_)57LB2`Z!5:YYV!SL\$`2..`\O``
M!,**RF+!UKD:`(.SS0`TN8(`<>.@\N@`!,*JRF+!UKD:`*VY&@"G['$BOSY5
MN0@`H^QQ`B$>5NQ:.[\E5;GG<-;L6B`Z!5:Y@@#9XQ#R^``$N1H`C<(:RF+!
MUKD(`(6Y&@`6[&DBOSY5[&D"(1Y6[)@[OR55N>=@5^R8(#H%5KF"`%JY&@`5
MN0@`&>S1.[\E5>S1(#H%5NR:(K\^5>,P\P``!.R:`B$>5L(ZRF+!UKGGD%:Y
M&@`WN8(`6+D:`#6Y"``][-,[OR55[-,@.@56XZ#S"``$L\$`7<*JRF+!UN/0
M\Q``!+D:`*;"VLIBP=;L:"*_/E6Y&@#9[&@"(1Y6N>=@B;/-`)6Y@@"!N1H`
MJ.R!(K\^5>R!`B$>5KGG@':Y@@!SN0@`J;D:`-?L6CN_)57L<R*_/E7L6B`Z
M!5;L<P(A'E:Y!``WXS`@(``(P#H`````XS`@(``DXQ#S&``$PAK*8L'6N1H`
M%KGH4&VYYW#8[)8@OP!5N>>@/>Q6.[\E5;D:`!/L60`Z!5:Y"``5[-HBOSY5
MZUD``@`,[-H"(1Y6[%D`(1Y6N>?0-[D(`%2YZ`!]P%H`````XU`@$``DN>=@
M`\!Z`````.-P(!@`).QA(+\`5>.@\R``!,*JRF+!UKD(`.JY&@#H[($[OR55
MN1H`X.R&`#H%5N,0\*``!+D(`.BY"``6P.H`````X^`@```DP!H`````XQ`@
M"``DU0?S*+`HIW0`"NMO\V``!`?^N00`#:?T]0?`Y?__X/X'!^OO\'``)*<I
M`(#C\/]@_W'`Y?__X*+`,6=%(P'`#^_-JXGC,"```"3C`"`(`"3`3YBZW/[`
M41`R5';C0"`0`"3C4"`8`"3`/\/2X?#E2"`H``#C,"`@`"3E2"`P``#E3"!X
M``#K[_$0``0'_@<'!P?K;_`P`"3K%``#``VY!`!RXR`@*``$N0@`$NQ1(+\`
M5;D$`+3C\/]8_W'C0'`P``2Y!`#3N3$`(:?$``2G2P`!XU!P*``DZPL`'0`,
MN0@`!.,`<#``).,P<'@`$J=T`&1!8'`X[+P`.#]^[.O_P`#8[)T`0`#9ZXX`
M!@#>IXH``1+NIQ@``;GR4(%!('!XN00`K>,@\*``)+DA`&JGI``UXU#PH``$
M[%H`-R!EN00`V=(_8`"@`+D$`">GNO_`IZL`0,#E___T&[D4`+NGFP!`IX;_
MY+DA`&VG1``@I\0`!KGHL$VY84!DN00`/;D$`":Y!`!+P.7__]^84+!P>.MO
M\-@`!`?^N00`V:?$_]/L:?_1H&6G]``!N>BP!KEA0-"G]/_DIZ@`0!NC&:M!
M8'`XN?(PJ[D$`":Y&``CN10`2NPM`"*@9;GH0(*YZ$"=N6%`V+D$`#T8VL#E
M___?9EK0<'A0T'!X[-;_S$!^N00`)QNZN00`V<#E___SP;D4`+NG]/]RN>A`
MG>PM_^7`9;EA0"FG]/_@!P?K?_`X`"2Y!`"SXX`P*``$XY`P,``$[!@ZOSU5
MN10`,4%#L#B2@$``IQH``;D$`**Y%``!02"P../P_V#_<;D(`"#L'`">.'ZG
MZ`!`N?D0/NSA`%^`=NP3__\`V+D$`#+K00`(`-[L2`!/`'[L=/__`-@85.P$
M/K\`5:>$`";L"``9`7[L"``,`G[C("0``#881T$P(0#7_R``(`#C(#0``#:G
M2O__U_\P`#``03`Q`.,@-```-M?_,``P`$$P,0#L2``B`7[K)0`"`-[C(#0`
M`#;7_S``,`#C(#4``#;7_S$`,0#C(#8``#;7_S(`,@#C(#<``#;7_S,`,P!!
M,#0`IR;_YKD6`.'&X````*"Y!``KP.7___,GUS>P.+`XISD``.PY``=@5>PY
M"`]@5>PY$!=@5>PY&!\@5;D$`"OL@P`?`%7C@+!P`"3`Y?__\PO2`Z``L`2Y
M!``KT@.@!+`,T@.@"+`4T@.@#+`<T@.@$+`DZW_PV``$P/3__^&JIU@`.+GY
M$'7L4?_,@';L%___`-BY!``RZW$`"`#>['@`3P!^[.?__P#8&%?L!SZ_`%6G
MA``F[`@`&0%^[`@`#`)^XR`D```V&'Y!,"$`U_\@`"``XR`T```VIWK__]?_
M,``P`$$P,0#C(#0``#;7_S``,`!!,#$`['@`(@%^ZT4``@#>XR`T```VU_\P
M`#``XR`U```VU_\Q`#$`XR`V```VU_\R`#(`XR`W```VU_\S`#,`03`T`*=&
M_^:Y%@`AQB`````(I_3_;=<`,``P`-<`,``P``<'!P?K[_!P`"2Y!``/I_O_
M8.,`\```).OO\1``!`?^`````"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```97AE`"]P<F]C+R5I+R5S
M`"X`4$%27U1%35```%!!4E]04D]'3D%-10``.@`O`%!%4DPU3$E"``!015),
M3$E"`%!%4DPU3U!4``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'``!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2``!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``;'-E96L@9F%I;&5D``!R96%D
M(&9A:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X``!P87(M```E
M<R5S)7,E<P``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@
M>6]U<B!O<&5R871I;VXI"@``4$%42```<&%R;```+G!A<@``<VAO<G0@<F5A
M9```)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M
M)74E<P``&`!P97)L```P`%!!4CHZ4&%C:V5R.CI615)324].```Q+C`V,0!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``)7,Z(&-R96%T:6]N
M(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``+64``"TM``!54T52``!54T523D%-10``5$5-4$1)4@!435``
M+W1M<```979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K
M86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I
M>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH
M(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")0
M2UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]
M($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M
M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT
M:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@
M)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L
M96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@
M)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S
M("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE
M;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A
M<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@
M*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO
M9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V
M+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N
M86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*
M7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE
M*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=
M*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N
M<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T
M(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC
M(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P
M.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F
M(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").
M;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q
M6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L
M("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@
M)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O
M9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T
M96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B
M1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F
M=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL
M;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF
M7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI
M>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^
M("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T[
M"G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E
M*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF
M:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T
M(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)
M0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@
M;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P
M87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?
M34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=
M.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97([
M"FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?
M1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92![
M"FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T
M;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X[
M"F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S
M*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T
M(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#
M3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?
M;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*
M?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F
M:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B
M)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C
M=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D[
M"GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R
M(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T
M7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`
M7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A
M=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@
M*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB
M.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER
M92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q
M=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*
M<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR
M97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A
M8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@
M+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J
M(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H
M95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII
M9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P
M*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*
M+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM
M(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A
M9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O
M9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*
M?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*
M)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L
M:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I
M"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@
M7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B
M?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%2
M7T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,``$-!0TA%
M```````````!&P,[````U````!G__X(````%:/__A@@```#P__^&Z````5#_
M_X=X```!@/__B-@```&X__^+8````?C__XO8```"-/__C!````)(__^-.```
M`HS__XU````"H/__C[````+@__^/Z````PS__Y%0```#4/__EN````.$__^7
M6````[3__Y?0```#X/__F>````0D__^:$```!$3__YKP```$E/__H2@```3D
M__^CH```!23__Z1P```%J/__NP@```7H__^[>```!@S__[T0```&2```````
M```4``````%Z4@`!>`X!&PP/H`$```````!<````'/__A1````#<`$:&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.P`("F`K/SLW,R\K)R,?&#J`!0@M<"L_.S<S+
MRLG(Q\8.H`%""TX*S\[-S,O*R<C'Q@Z@`4(+```````L````?/__A9````"0
M`$:*"HL)C`B-!XX&CP5&#M@#`GP*S\[-S,O*#J`!0@L````T````K/__A?``
M``%@`$:(#(D+B@J+"8P(C0>.!H\%1@[8`W8*S\[-S,O*R<@.H`%""P``````
M`#P```#D__^'&````H@`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[8`@,!5@K/
MSLW,R\K)R,?&#J`!0@L````````X```!)/__B6````!T`$R&#H<-B`R)"XH*
MBPF,"(T'C@:/!48.R`("8,_.S<S+RLG(Q\8.H`$````````0```!8/__B9P`
M```X`````````$````%T__^)P````20`1H8.APV(#(D+B@J+"8P(C0>.!H\%
M1@Z@(4P.H$%,#M!"`N0*S\[-S,O*R<C'Q@Z@`4(+````$````;C__XJD````
M!@`````````\```!S/__BI@```)L`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.
MH"%,#N@C`GH*S\[-S,O*R<C'Q@Z@`4(+````*````@S__XS(````-`!*BPF,
M"(T'C@:/!48.P`)>S\[-S,L.H`$```````!````"./__C-0```%B`$:*"HL)
MC`B-!XX&CP5&#J`A3`[((@+T"L_.S<S+R@Z@`4(+7`K/SLW,R\H.H`%&"P``
M`````#````)\__^-^```!8P`1HH*BPF,"(T'C@:/!48.T`(#!4H*S\[-S,O*
M#J`!1@L````````L```"L/__DU0```!V`$R+"8P(C0>.!H\%1@[0`@)4"L_.
MS<S+#J`!0@L````````H```"X/__DYP```!T`%R&#H<-B`R)"XH*BPF,"(T'
MC@:/!48.Z`(``````$````,,__^3Z````A``1H@,B0N*"HL)C`B-!XX&CP5&
M#`Z@@018#0]&#M""!`,!I`K/SLW,R\K)R`Z@`4(+````````'````U#__Y6T
M````+`!&C@:/!48.P`)>S\X.H`$```!,```#</__E<0```#:`$:&#H<-B`R)
M"XH*BPF,"(T'C@:/!48.T`("6@K/SLW,R\K)R,?&#J`!0@L"9@K/SLW,R\K)
MR,?&#J`!1@L``````$P```/`__^65```!C@`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%1@Z`!0,"8`K/SLW,R\K)R,?&#J`!0@L#`J(*S\[-S,O*R<C'Q@Z@`48+
M````/```!!#__YP\```"=`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P&^
M"L_.S<S+RLG(Q\8.H`%""P```````$````10__^>=````,X`1HD+B@J+"8P(
MC0>.!H\%1@[0`@)>"L_.S<S+RLD.H`%""P)6"L_.S<S+RLD.H`%&"P``````
M/```!)3__WR0```"@`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N@"`P'`"L_.
MS<S+RLG(Q\8.H`%""P```````#P```34__^>P```%I8`1H8.APV(#(D+B@J+
M"8P(C0>.!H\%1@[0!P,6>@K/SLW,R\K)R,?&#J`!0@L````````@```%%/__
MM1@```!L`$J.!H\%1@[``@):S\X.H`$````````X```%./__M60```&6`$R&
M#H<-B`R)"XH*BPF,"(T'C@:/!5X.R`("V@K/SLW,R\K)R,?&#J`!0@L````X
M```%=/__ML````)4`$:'#8@,B0N*"HL)C`B-!XX&CP5X#L`"`P$Z"L_.S<S+
MRLG(QPZ@`48+````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````(U`````````BZ``````````!`````````L@``````````0``
M``````+3`````````!T````````$!0`````````,````````&$@`````````
M#0```````%SP`````````!D```````"[P``````````;``````````@`````
M````&@```````+O(`````````!P`````````"`````!O__[U`````````G@`
M````````!0````````Q```````````8````````#6``````````*````````
M!",`````````"P`````````8`````````!4````````````````````#````
M````O;```````````@````````5``````````!0`````````!P`````````7
M````````$P@`````````!P```````!!H``````````@````````"H```````
M```)`````````!@`````````'@`````````(`````&____L`````"````0``
M``!O___Y`````````!``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````+O0`````````````````````````````!B2````````&+(`
M```````8T@```````!CR````````&1(````````9,@```````!E2````````
M&7(````````9D@```````!FR````````&=(````````9\@```````!H2````
M````&C(````````:4@```````!IR````````&I(````````:L@```````!K2
M````````&O(````````;$@```````!LR````````&U(````````;<@``````
M`!N2````````&[(````````;T@```````!OR````````'!(````````<,@``
M`````!Q2````````''(````````<D@```````!RR````````'-(````````<
M\@```````!T2````````'3(````````=4@```````!UR````````'9(`````
M```=L@```````!W2````````'?(````````>$@```````!XR````````'E(`
M```````><@```````!Z2````````'K(````````>T@```````![R````````
M'Q(````````?,@```````!]2````````'W(`````````````````````````
M```````````````82```````````````````````````````````````````
M```````````````````?B```````````````````7/``````````````````
M``````````````````````#```I005(N<&T*``````````````````!?^@``
M`````%U8``````````````````!=^````````%W\````````7^X```````!=
M7@```````%_V``````````````````!?W@```````%_D````````````````
M``!@`$=#0SH@*$%L<&EN92`Q,RXR+C%?9VET,C`R,S$P,30I(#$S+C(N,2`R
M,#(S,3`Q-```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`
M+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````````
M````````````````````````````````````````````````````````````
M``````L````!``````````(````````".`````````(X`````````!@`````
M```````````````!```````````````3````!P`````````"`````````E``
M```````"4``````````D````````````````````!```````````````)F__
M__8``````````@````````)X`````````G@`````````W`````0`````````
M``````@``````````````#`````+``````````(````````#6`````````-8
M````````".@````%`````@`````````(`````````!@````X`````P``````
M```"````````#$`````````,0`````````0C`````````````````````0``
M````````````0`````0``````````@```````!!H````````$&@````````"
MH`````0```````````````@`````````&````$H````$`````````$(`````
M```3"````````!,(````````!4`````$````$@`````````(`````````!@`
M``!4`````0`````````&````````&$@````````82``````````<````````
M`````````````@``````````````3P````$`````````!@```````!AD````
M````&&0````````'(`````````````````````0`````````(````%H````!
M``````````8````````?B````````!^(````````/6@`````````````````
M```(``````````````!@`````0`````````&````````7/````````!<\```
M```````<`````````````````````@``````````````9@````$`````````
M`@```````%T0````````71````````!`>`````````````````````@`````
M`````````&X````!``````````(```````"=B````````)V(`````````-0`
M```````````````````$``````````````!\`````0`````````"````````
MGF````````">8`````````6P````````````````````"```````````````
MA@````X``````````P```````+O`````````J\``````````"```````````
M``````````@`````````"````)(````/``````````,```````"[R```````
M`*O(``````````@````````````````````(``````````@```">````!@``
M```````#````````N]````````"KT`````````'@````!0``````````````
M"``````````0````IP````$``````````P```````+VP````````K;``````
M```"4`````````````````````@`````````"````*P````!``````````,`
M``````#``````````+```````````(`````````````````````(````````
M``````"R````"``````````#````````P(````````"P@`````````!8````
M````````````````"```````````````MP````$`````````,```````````
M````````L(``````````,0````````````````````$``````````0````$`
M```#`````````````````````````````+"Q`````````,``````````````
.```````!````````````
